//[mahjong-utils](../../../../index.md)/[mahjongutils.models](../../index.md)/[Mentsu](../index.md)/[Companion](index.md)/[invoke](invoke.md)

# invoke

[common]\
operator fun [invoke](invoke.md)(tiles: [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Tile](../../-tile/index.md)&gt;): [Mentsu](../index.md)

operator fun [invoke](invoke.md)(text: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)): [Mentsu](../index.md)
